package com.bpcl.lpg.core.cronjob;

import org.slf4j.LoggerFactory;
import de.hybris.platform.cronjob.model.CronJobModel;
import java.util.Iterator;
import java.util.List;
import java.text.MessageFormat;
import com.bpcl.core.util.BPCLDateUtils;
import de.hybris.platform.cronjob.enums.CronJobStatus;
import de.hybris.platform.cronjob.enums.CronJobResult;
import de.hybris.platform.core.model.user.CustomerModel;
import java.util.Collection;
import org.apache.commons.collections4.CollectionUtils;
import java.util.Objects;
import com.bpcl.core.model.UserOTPModel;
import de.hybris.platform.servicelayer.cronjob.PerformResult;
import com.bpcl.core.ym.notication.service.LpgV2NotificationEngineService;
import de.hybris.platform.servicelayer.config.ConfigurationService;
import com.bpcl.core.ym.notication.service.NotificationEngineService;
import javax.annotation.Resource;
import com.bpcl.core.customer.dao.BpclCustomerDao;
import com.bpcl.core.user.otp.dao.BpclOTPGenericDao;
import org.slf4j.Logger;
import com.bpcl.core.model.BpclCronjobModel;
import de.hybris.platform.servicelayer.cronjob.AbstractJobPerformable;

public class ResetUserOtpCountJob extends AbstractJobPerformable<BpclCronjobModel>
{
    private static final Logger LOG;
    private BpclOTPGenericDao otpGenericDao;
    @Resource(name = "bpclCustomerDao")
    private BpclCustomerDao bpclCustomerDao;
    private NotificationEngineService notificationEngineService;
    private ConfigurationService configurationService;
    private LpgV2NotificationEngineService lpgV2NotificationEngineService;
    
    public PerformResult perform(final BpclCronjobModel cronJob) {
        ResetUserOtpCountJob.LOG.info("User otp reset job started on {}", cronJob.getStartTime());
        try {
            final List<UserOTPModel> userOTPModels = this.otpGenericDao.fetchOTPModelByNoOfResendAttempts();
            ResetUserOtpCountJob.LOG.info("No of entries {}", (Object)userOTPModels.size());
            for (final UserOTPModel otp : userOTPModels) {
                if (Objects.nonNull(otp)) {
                    ResetUserOtpCountJob.LOG.info("Processing user {}", otp.getCustomerId());
                    otp.setNoOfResendAttempt(Integer.valueOf(0));
                    this.modelService.save((Object)otp);
                }
            }
            ResetUserOtpCountJob.LOG.info("Reset otp count cronjob is performed successfully");
            final List<CustomerModel> customers = this.bpclCustomerDao.getCustomersBySentMailCount();
            if (CollectionUtils.isNotEmpty((Collection)customers)) {
                for (final CustomerModel customerModel : customers) {
                    customerModel.setSentMailCount(Integer.valueOf(0));
                    this.modelService.save((Object)customerModel);
                }
            }
            ResetUserOtpCountJob.LOG.info("Customer mail count set to 0");
            return new PerformResult(CronJobResult.SUCCESS, CronJobStatus.FINISHED);
        }
        catch (final Exception ex) {
            ResetUserOtpCountJob.LOG.error(ex.getMessage(), ex.getCause());
            final String body = MessageFormat.format("Reset user OTP cronjob is failed due to exception at {0}", BPCLDateUtils.getCurrentDateAsString("dd-MMM-yy h:mm a"));
            this.lpgV2NotificationEngineService.sendEmail("FAILED Reset User OTP Job Alert", body, this.configurationService.getConfiguration().getString("lpg.alert.email.receiver.id"));
            return new PerformResult(CronJobResult.FAILURE, CronJobStatus.ABORTED);
        }
    }
    
    public boolean isAbortable() {
        return Boolean.TRUE;
    }
    
    public void setOtpGenericDao(final BpclOTPGenericDao otpGenericDao) {
        this.otpGenericDao = otpGenericDao;
    }
    
    public void setNotificationEngineService(final NotificationEngineService notificationEngineService) {
        this.notificationEngineService = notificationEngineService;
    }
    
    public void setConfigurationService(final ConfigurationService configurationService) {
        this.configurationService = configurationService;
    }
    
    public LpgV2NotificationEngineService getLpgV2NotificationEngineService() {
        return this.lpgV2NotificationEngineService;
    }
    
    public void setLpgV2NotificationEngineService(final LpgV2NotificationEngineService lpgV2NotificationEngineService) {
        this.lpgV2NotificationEngineService = lpgV2NotificationEngineService;
    }
    
    static {
        LOG = LoggerFactory.getLogger(ResetUserOtpCountJob.class);
    }
}
